This object was generated using the TxDb.Hsapiens.UCSC.hg19.knownGene package. The script used for this object is found in the inst/scripts directory
Usage
data(hg38.tx.gr, package = "compartmap")Author
James Eapen james.eapen@vai.org
This object was generated using the TxDb.Hsapiens.UCSC.hg19.knownGene package. The script used for this object is found in the inst/scripts directory
data(hg38.tx.gr, package = "compartmap")James Eapen james.eapen@vai.org