This object was generated using the TxDb.Mmusculus.UCSC.mm10.knownGene package. The script used for this object is found in the inst/scripts directory
Usage
data(mm10.tx.gr, package = "compartmap")Author
James Eapen james.eapen@vai.org
This object was generated using the TxDb.Mmusculus.UCSC.mm10.knownGene package. The script used for this object is found in the inst/scripts directory
data(mm10.tx.gr, package = "compartmap")James Eapen james.eapen@vai.org